////////////////////////////////////////////////////////////////////////////////
// Programme de test d'une carte arduino pour l'application PPCaP             //
// P. Pénard le 25 11 2014                                                    //
// Le but est de déterminer si toutes les entrées/sorties qui sont utilisées  //
// pour PPCaP sont fonctionnelles                                             //
//                                                                            //
// Mise en oeuvre :                                                           //
// - Raccorder la carte arduino à tester, seule, sans la platine PPCaP        //
// - Compiler et télécharger ce programme dans la carte                       //
// - Laisser la carte raccordée à l'USB pour son alimentation                 //
// - Lancer le terminal (vérifier qu'il est bien à 9600 bauds)                //
//                                                                            //
// Matériel nécessaire :                                                      //
// - Une led de test : une led en série avec une résistance de 300 Ohms,      //
//   cathode connectée sur une des 2 broches GND côté connecteur analogique   //
// - Une sonde de masse : un fil et une résistance de 2.2 kOhms en série      //
//   une extrémité est connectée à l'autre broche GND côté analogique         //
// - Un interrupteur : à brancher entre le GND côté Digital et la broche 6    //
//                                                                            //
//        Ce programme peut être modifié et diffusé sans limitation  !        //
//                                                                            //
////////////////////////////////////////////////////////////////////////////////

// Les broches utilisées et leur rôle dans PPCaP
// Registre à décalage 74HC595
int latchPin = 8;   // ST_CP
int clockPin = 12;  // SH_CP
int dataPin = 11;   // DS
int enablePin = 10; // OE
// Interruptions pour comptage des impulsions
int encoder_PinA = 2;
int encoder_PinB = 3;
// Bouton de commande
int bouton_com = 6;
// Détection d'un circuit imprimé 42 notes
int ci_42 = 9;
// Etat du contact présence carte
int carte_pres = 7;
// Mesure de tension batterie
int mesurebatt = A0;
// Les deux LEDs : une rouge et une verte.
int led_rouge = 4; 
int led_verte = 5;
// Les signaux de lecture/écriture sur la carte à mémoire
int cap_clk = A5;
int cap_data = A4;

void setup() {
  Serial.begin(9600);
  pinMode(latchPin, OUTPUT);      
  pinMode(clockPin, OUTPUT);      
  pinMode(dataPin, OUTPUT);       
  pinMode(enablePin, OUTPUT);    
  pinMode(encoder_PinA, INPUT);  
  pinMode(encoder_PinB, INPUT);  
  pinMode(bouton_com, INPUT);    
  pinMode(ci_42, INPUT);
  pinMode(carte_pres, INPUT);    
  pinMode(mesurebatt, INPUT);    
  pinMode(led_rouge, OUTPUT);   
  pinMode(led_verte, OUTPUT);
  pinMode(cap_clk, OUTPUT);
  pinMode(cap_data, OUTPUT);
  digitalWrite(encoder_PinA, HIGH); digitalWrite(encoder_PinB, HIGH); digitalWrite(carte_pres, HIGH);
  digitalWrite(ci_42, HIGH); digitalWrite(bouton_com, HIGH);
  Serial.println("*** Test d'une carte arduino pour l'application PPCaP ***");
  Serial.println("-> On progresse dans les tests en appuyant sur le bouton");
  Serial.println();
}

void loop() {  
  int phase = 0;
  boolean button_pushed = false, msg = true;
  while(true) {
    while (digitalRead(bouton_com) == LOW) {  
       delay(20);
       button_pushed = true;
    }
    if (button_pushed){
      phase ++; msg = true;
      button_pushed = false;
      if (phase >= 9) {pinMode(cap_clk, INPUT);pinMode(cap_data, INPUT);}
    }
    switch(phase){
     case 1 : {
         if (msg){
           Serial.println("VERIFICATION DES ENTREES/SORTIES : La led de test doit clignoter");
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 8 (latchPin)");
           Serial.println("Brancher la sonde de masse sur la broche 2 (encoder_PinA)");
         }
         if (digitalRead(encoder_PinA) == LOW) digitalWrite(latchPin, HIGH); else digitalWrite(latchPin, LOW);     
         delay(100); digitalWrite(latchPin, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 2 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 10 (enablePin)");
           Serial.println("Brancher la sonde de masse sur la broche 3 (encoder_PinB)");
         }
         if (digitalRead(encoder_PinB) == LOW) digitalWrite(enablePin, HIGH); else digitalWrite(enablePin, LOW);     
         delay(100); digitalWrite(enablePin, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 3 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 11 (dataPin)");
           Serial.println("Brancher la sonde de masse sur la broche 7 (carte_pres)");
         }
         if (digitalRead(carte_pres) == LOW) digitalWrite(dataPin, HIGH); else digitalWrite(dataPin, LOW);     
         delay(100); digitalWrite(dataPin, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 4 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 12 (clockPin)");
           Serial.println("Brancher la sonde de masse sur la broche 9 (ci_42)");
         }
         if (digitalRead(ci_42) == LOW) digitalWrite(clockPin, HIGH); else digitalWrite(clockPin, LOW);     
         delay(100); digitalWrite(clockPin, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 5 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 4 (led_rouge)");
           Serial.println("Laisser la sonde de masse sur la broche 9 (ci_42)");
         }
         if (digitalRead(ci_42) == LOW) digitalWrite(led_rouge, HIGH); else digitalWrite(led_rouge, LOW);     
         delay(100); digitalWrite(led_rouge, LOW); delay(100);
         msg = false; 
         break;    
     }     
     case 6 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 5 (led_verte)");
           Serial.println("Laisser la sonde de masse sur la broche 9 (ci_42)");
         }
         if (digitalRead(ci_42) == LOW) digitalWrite(led_verte, HIGH); else digitalWrite(led_verte, LOW);     
         delay(100); digitalWrite(led_verte, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 7 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche A4 (cap_data en Output)");
           Serial.println("Laisser la sonde de masse sur la broche 9 (ci_42)");
         }
         if (digitalRead(ci_42) == LOW) digitalWrite(cap_data, HIGH); else digitalWrite(cap_data, LOW);     
         delay(100); digitalWrite(cap_data, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 8 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche A5 (cap_clk en Output)");
           Serial.println("Laisser la sonde de masse sur la broche 9 (ci_42)");
         }
         if (digitalRead(ci_42) == LOW) digitalWrite(cap_clk, HIGH); else digitalWrite(cap_clk, LOW);     
         delay(100); digitalWrite(cap_clk, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 9 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Brancher la led de test sur la broche 5 (led_verte)");
           Serial.println("Brancher la sonde de masse sur la broche A4 (cap_data en Input)");
         }
         if (digitalRead(cap_data) == LOW) digitalWrite(led_verte, HIGH); else digitalWrite(led_verte, LOW);     
         delay(100); digitalWrite(led_verte, LOW); delay(100);
         msg = false; 
         break;    
     }
     case 10 : {
         if (msg){
           Serial.println(phase);
           Serial.println("Laisser la led de test sur la broche 5 (led_verte)");
           Serial.println("Brancher la sonde de masse sur la broche A5 (cap_clk en Input)");
         }
         if (digitalRead(cap_clk) == LOW) digitalWrite(led_verte, HIGH); else digitalWrite(led_verte, LOW);     
         delay(100); digitalWrite(led_verte, LOW); delay(100);
         msg = false; 
         break;    
     }   
     case 11 : {
         if (msg){
           Serial.println();
           Serial.println("VERIFICATION DE LA MESURE DE TENSION BATTERIE");
           Serial.println(phase - 10);
           Serial.println("Brancher la sonde de masse entre le 5V et la broche A0 (mesurebatt)");
         }
         msg = false; 
         break;    
     }
     case 12 : {
         if (msg){
           Serial.println(phase - 10);
           Serial.println("On doit mesurer une valeur proche de 1023");
           int tensionbatt = analogRead(mesurebatt);
           Serial.print("Mesure 5 V = ");
           Serial.println(tensionbatt);
         }
         msg = false; 
         break;    
     }
     case 13 : {
         if (msg){
           Serial.println(phase - 10);
           Serial.println("Brancher la sonde de masse entre le 3.3 V et la broche A0 (mesurebatt)");
         }
         msg = false; 
         break;    
     }
     case 14 : {
         if (msg){
           Serial.println(phase - 10);
           Serial.println("On doit mesurer une valeur aux environs de 670");
           int tensionbatt = analogRead(mesurebatt);
           Serial.print("Mesure 3.3 V = ");
           Serial.println(tensionbatt);
         }
         msg = false; 
         break;    
     }
     case 15 : {
         if (msg){
           Serial.println();
           Serial.println("VERIFICATION DE LA BROCHE TX");
           Serial.println("Brancher la led de test sur la broche 1 (TX)");
           Serial.println("Verifier son clignotement pendant le message de fin au test suivant");         
         }
         msg = false; 
         break;    
     }
     case 16 : {
         if (msg){
           Serial.println();
           for (int i = 0; i<10; i++) {
             Serial.println("Fin des test pour l'applications PPCaP");
             delay(500);
           }
         }
         msg = false; 
         break;    
     }
    } 
  }
}

